@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 use base qw(Class::Accessor);
 use Crypt::OpenSSL::X509 qw(FORMAT_ASN1);
@@ -190,8 +190,6 @@ sub _peer_certificate {
         if ($record->{type} != $SSL3_RT_HANDSHAKE) {
             if ($record->{type} == $SSL3_RT_ALERT) {
                 my $d1 = unpack 'C', substr $record->{data}, 0, 1;
-                p $d1;
-                p $SSL3_AL_WARNING;
                 if ($d1 eq $SSL3_AL_WARNING) {
                     ; # go ahead
                 } else {
